==> owncloud-app-documents-1%3A0.10.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/ca.php <==
<?php
$TRANSLATIONS = array(
"Documents" => "Documents",
"Can't create document" => "El document no es pot crear",
"You don't have permission to rename this document" => "No teniu permisos per canviar de nom aquest document",
"Directory saved successfully." => "La carpeta s'ha desat correctament",
"An error occurred while changing directory." => "S'ha produït un error en canviar de carpeta",
"Saved" => "Desat",
"Format filter server is down or misconfigured" => "El servidor de filtres de format ha caigut o està mal configurat",
"Conversion failed. Check log for details." => "La conversió ha fallat. Mireu el log per a més detalls.",
"document-styles" => "document-styles",
"document-content" => "document-content",
"bold" => "Negreta",
"italic" => "Cursiva",
"solid" => "sòlid",
"pt" => "pt",
"Saving..." => "Desant...",
"Failed to load documents." => "Ha fallat en carregar documents.",
"No documents were found. Upload or create a document to get started!" => "No hi ha documents. Pugeu o creeu un document per començar!",
"No connection to server. Trying to reconnect." => "No hi ha connexió amb el servidor Intentant reconnectar.",
"Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." => "Deixant aquesta pàgina en mode editor poden quedar dades sense desar. Es recomana usar el botó 'Tanca'.",
"Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." => "Ha fallat la càrrega d'aquest document. Comproveu si es pot obrir amb un editor odt extern. Això podria significar que s'ha deixat de compartir o eliminat recentment.",
"Save" => "Desa",
"Loading documents..." => "S'estan carregant els documents...",
"'.' is an invalid file name." => "'.' és un nom no vàlid per un fitxer.",
"File name cannot be empty." => "El nom del fitxer no pot ser buit.",
"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "El nóm no és vàlid, '\\', '/', '<', '>', ':', '\"', '|', '?' i '*' no estan permesos.",
"Align Left" => "Alinea a l'esquerra",
"Alignment" => "Alineament",
"Align Right" => "Alinea a la dreta",
"Annotate" => "Anota",
"Background" => "Fons",
"Bold" => "Negreta",
"Bottom" => "A baix",
"Cancel" => "Cancel·la",
"Center" => "Centra",
"Clone" => "Clona",
"Clone this Style" => "Clona aquest estil",
"Close" => "Tanca",
"Color" => "Color",
"Create" => "Crea",
"Decrease Indent" => "Decrementa la identació",
"Default Style" => "Estil predeterminat",
"Delete" => "Esborra",
"Family" => "Familia",
"Font" => "Lletra",
"Font Effects" => "Efectes de lletra",
"Format" => "Format",
"Increase Indent" => "Incrementa la identació",
"Insert Image" => "Insereix imatge",
"Invite Members" => "Convida a membres",
"Italic" => "Cursiva",
"Justified" => "Justificat",
"Justify" => "Justifica",
"Left" => "Esquerra",
"Loading" => "Carregant",
"Members" => "Membres",
"New Name:" => "Nom nou:",
"OK" => "D'acord",
"Open" => "Obre",
"Options" => "Options",
"Paragraph..." => "Paràgraf...",
"Paragraph Styles" => "Estils de paràgraf",
"Redo" => "Refés",
"Right" => "Dreta",
"Size" => "Mida",
"Spacing" => "Espaiat",
"Strikethrough" => "Ratllat",
"Style" => "Estil",
"Text" => "Text",
"Top" => "A dalt",
"Underline" => "Subratllat",
"Undo" => "Desfés",
"Unknown Author" => "Autor desconegut",
"Edit" => "Edita",
"Share" => "Comparteix",
"guest" => "convidat",
"MS Word support (requires openOffice/libreOffice)" => "compatibilitat amb MS Word (requereix openOffice/libreOffice)",
"Local" => "Local",
"openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" => "openOffice/libreOffice està instal·ñlat en aquest servidor. La carpeta al binari es proporciona via preview_libreoffice_path a config.php",
"External" => "Extern",
"openOffice/libreOffice is installed on external server running a format filter server" => "openOffice/libreOffice està instal·lat en un servidor extern executant un servidor de filtrat de formats",
"Disabled" => "Desactivat",
"No MS Word support" => "Sense suport per a MS Word",
"scheme://domain.tld[:port]" => "esquema://domini.tld[:port]",
"Server URL" => "URL del servidor",
"Apply and test" => "Aplica i testeja",
"New document" => "Document nou",
"Upload (max. %s)" => "Pujada (màx. %s)",
"Upload" => "Puja",
"Save new documents to" => "Desa els documents nous a",
"Wrong password. Please retry." => "Contrasenya incorrecta. Intenteu-ho de nou.",
"Password" => "Contrasenya",
"Guest %s" => "Convidat %s",
"This link has been expired or is never existed. Please contact the person who shared it with you for details." => "Aquest enllaç ha vençut o no ha existit mai. Contacteu amb la persona que l'ha compartit amb vós per més detalls.",
"Advanced feature-set" => "Joc d'opcions avançades",
"(Unstable)" => "(Inestable)"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";

==> owncloud-app-documents-1%3A0.13.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/ca.php <==
<?php
$TRANSLATIONS = array(
"Documents" => "Documents",
"Can't create document" => "El document no es pot crear",
"You don't have permission to rename this document" => "No teniu permisos per canviar de nom aquest document",
"Directory saved successfully." => "La carpeta s'ha desat correctament",
"An error occurred while changing directory." => "S'ha produït un error en canviar de carpeta",
"Saved" => "Desat",
"Format filter server is down or misconfigured" => "El servidor de filtres de format ha caigut o està mal configurat",
"Conversion failed. Check log for details." => "La conversió ha fallat. Mireu el log per a més detalls.",
"Saving..." => "Desant...",
"Failed to load documents." => "Ha fallat en carregar documents.",
"No documents were found. Upload or create a document to get started!" => "No hi ha documents. Pugeu o creeu un document per començar!",
"No connection to server. Trying to reconnect." => "No hi ha connexió amb el servidor Intentant reconnectar.",
"Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." => "Deixant aquesta pàgina en mode editor poden quedar dades sense desar. Es recomana usar el botó 'Tanca'.",
"Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." => "Ha fallat la càrrega d'aquest document. Comproveu si es pot obrir amb un editor odt extern. Això podria significar que s'ha deixat de compartir o eliminat recentment.",
"Save" => "Desa",
"Loading documents..." => "S'estan carregant els documents...",
"'.' is an invalid file name." => "'.' és un nom no vàlid per un fitxer.",
"File name cannot be empty." => "El nom del fitxer no pot ser buit.",
"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "El nóm no és vàlid, '\\', '/', '<', '>', ':', '\"', '|', '?' i '*' no estan permesos.",
"Align Left" => "Alinea a l'esquerra",
"Alignment" => "Alineament",
"Align Right" => "Alinea a la dreta",
"Annotate" => "Anota",
"Background" => "Fons",
"Bold" => "Negreta",
"Bottom" => "A baix",
"Cancel" => "Cancel·la",
"Center" => "Centra",
"Clone" => "Clona",
"Clone this Style" => "Clona aquest estil",
"Close" => "Tanca",
"Color" => "Color",
"Create" => "Crea",
"Decrease Indent" => "Decrementa la identació",
"Default Style" => "Estil predeterminat",
"Delete" => "Esborra",
"Family" => "Familia",
"Font" => "Lletra",
"Font Effects" => "Efectes de lletra",
"Format" => "Format",
"Increase Indent" => "Incrementa la identació",
"Insert Image" => "Insereix imatge",
"Invite Members" => "Convida a membres",
"Italic" => "Cursiva",
"Justified" => "Justificat",
"Justify" => "Justifica",
"Left" => "Esquerra",
"Loading" => "Carregant",
"Members" => "Membres",
"New Name:" => "Nom nou:",
"OK" => "D'acord",
"Open" => "Obre",
"Options" => "Options",
"Paragraph..." => "Paràgraf...",
"Paragraph Styles" => "Estils de paràgraf",
"Redo" => "Refés",
"Right" => "Dreta",
"Size" => "Mida",
"Spacing" => "Espaiat",
"Strikethrough" => "Ratllat",
"Style" => "Estil",
"Text" => "Text",
"Top" => "A dalt",
"Underline" => "Subratllat",
"Undo" => "Desfés",
"Unknown Author" => "Autor desconegut",
"Shared" => "Compartit",
"Error" => "Error",
"Error while sharing" => "Error en compartir",
"Error while unsharing" => "Error en deixar de compartir",
"Error while changing permissions" => "Error en canviar els permisos",
"Shared with you and the group {group} by {owner}" => "Compartit amb vos i amb el grup {group} per {owner}",
"Shared with you by {owner}" => "Compartit amb vos per {owner}",
"Share with users or groups …" => "Comparteix amb usuaris o grups ...",
"Share with users, groups or remote users …" => "Comparteix amb usuaris, grups o usuaris remots ...",
"Share" => "Comparteix",
"Share with people on other ownClouds using the syntax username@example.com/owncloud" => "Compartir amb la gent en altres ownClouds utilitzant la sintaxi username@example.com/owncloud",
"Share link" => "Comparteix l'enllaç",
"The public link will expire no later than {days} days after it is created" => "L'enllaç públic tindrà venciment abans de {days} dies després de crear-lo",
"Link" => "Enllaç",
"Password protect" => "Protegir amb contrasenya",
"Password" => "Contrasenya",
"Choose a password for the public link" => "Escolliu una contrasenya per l'enllaç públic",
"Allow editing" => "Permetre edició",
"Email link to person" => "Enllaç per correu electrónic amb la persona",
"Send" => "Envia",
"Set expiration date" => "Estableix la data de venciment",
"Expiration" => "Expiració",
"Expiration date" => "Data de venciment",
"An error occured. Please try again" => "Va ocórrer un error. Per favor, intenta-ho de nou",
"Adding user..." => "Afegint usuari...",
"group" => "grup",
"remote" => "remot",
"Resharing is not allowed" => "No es permet compartir de nou",
"Shared in {item} with {user}" => "Compartit en {item} amb {user}",
"Unshare" => "Deixa de compartir",
"notify by email" => "notifica per correu electrònic",
"can share" => "pot compartir",
"can edit" => "pot editar",
"access control" => "control d'accés",
"create" => "crea",
"change" => "canvi",
"delete" => "elimina",
"Password protected" => "Protegeix amb contrasenya",
"Error unsetting expiration date" => "Error en eliminar la data de venciment",
"Error setting expiration date" => "Error en establir la data de venciment",
"Sending ..." => "Enviant...",
"Email sent" => "El correu electrónic s'ha enviat",
"Warning" => "Avís",
"Edit" => "Edita",
"guest" => "convidat",
"MS Word support (requires openOffice/libreOffice)" => "compatibilitat amb MS Word (requereix openOffice/libreOffice)",
"Local" => "Local",
"openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" => "openOffice/libreOffice està instal·ñlat en aquest servidor. La carpeta al binari es proporciona via preview_libreoffice_path a config.php",
"External" => "Extern",
"openOffice/libreOffice is installed on external server running a format filter server" => "openOffice/libreOffice està instal·lat en un servidor extern executant un servidor de filtrat de formats",
"Disabled" => "Desactivat",
"No MS Word support" => "Sense suport per a MS Word",
"scheme://domain.tld[:port]" => "esquema://domini.tld[:port]",
"Server URL" => "URL del servidor",
"Apply and test" => "Aplica i testeja",
"New document" => "Document nou",
"Upload (max. %s)" => "Pujada (màx. %s)",
"Upload" => "Puja",
"Save new documents to" => "Desa els documents nous a",
"Wrong password. Please retry." => "Contrasenya incorrecta. Intenteu-ho de nou.",
"Guest %s" => "Convidat %s",
"This link has been expired or is never existed. Please contact the person who shared it with you for details." => "Aquest enllaç ha vençut o no ha existit mai. Contacteu amb la persona que l'ha compartit amb vós per més detalls.",
"Advanced feature-set" => "Joc d'opcions avançades",
"(Unstable)" => "(Inestable)"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
